BackLeading class

Transparent back button (chevron or ×) that automatically adapts to:

  • iOS 26+ : native IosButtonWidget (SF Symbol via cupertino_native)
  • iOS <26 / Android : Material circle-icon button

RTL is derived from Localizations — no external locale package needed.

Inheritance

Constructors

BackLeading({Key? key, required bool isModalSheet, VoidCallback? onBack, bool havePadding = true, double? containerSize, double? iconSize})
const

Properties

containerSize double?
final
hashCode int
The hash code for this object.
no setterinherited
havePadding bool
final
iconSize double?
final
isModalSheet bool
When true the leading icon becomes × (close) instead of a back chevron.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onBack VoidCallback?
Overrides the default Navigator.maybePop tap handler.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited